@@ -18,6 +18,7 @@ names(results) <- c("Item/Cluster", "Item/Clust","similarity","correlation","alp
 rownames(results) <- paste("C",1:(num.var-1),sep="")
 digits <- ICLUST.options$digits
 clusters <- diag(1,nrow =nrow(r.mat))    #original cluster structure is 1 item clusters
+if(is.null(rownames(r.mat))) {rownames(r.mat) <-  paste("V",1:num.var,sep="") }
 rownames(clusters) <- rownames(r.mat)
 colnames(clusters) <- paste("V",1:num.var,sep="")
 diag(r.mat) <- 0
@@ -77,7 +78,7 @@ if ( ICLUST.options$reverse ) {            #normal case is to reflect if necessa
  	  	sign.max <- -1
 		max.cell <- min.cell }
 	if (sim[max.cell] < 0.0) {sign.max <- -1 }}  
-	               #this is a weird case where all the similarities are negative 
+	               #this is a weird case where all the similarities are negative  -- happens towards the end of clustering
 	
 max.col <- trunc(max.cell/nrow(sim))+1    #is in which row and column?
 max.row <- max.cell - (max.col-1)*nrow(sim) #need to fix the case of first column
@@ -118,12 +119,12 @@ if(size2 < 2) {V2 <- 1
 
 
 
-Cov12 <- sign.max * sim.mat[max.cell] * sqrt(V1*V2) 
+Cov12 <- sign.max * sim.mat[max.cell] * sqrt(V1*V2) #this flips the sign of the correlation for negative correlations
 r12 <- Cov12/(size1*size2)   #average between cluster r
-V12 <- V1 + V2 + 2 * Cov12
+V12 <- V1 + V2 + 2 * Cov12  #the variance of the new cluster
 
 size12 <- size1 + size2
-V12c <- (V12 - size12)*(size12/(size12-1))  #true variance
+V12c <- (V12 - size12)*(size12/(size12-1))  #true variance (using the average r on the diagonal)
 rbar <- V12c/(size12^2)
 alpha <- V12c/V12
 
@@ -144,32 +145,43 @@ if(ICLUST.options$weighted) {beta.combined <- beta.weighted} else {beta.combined
 #neither seems optimal, in that a) will correctly identify non-correlated clusters, but b) is less affected by small clusters.
 
 if(ICLUST.options$cor.gen) {
-c1 <-  r12 * size1 * size1 +  sign.max * Cov12  #corrected covariance?
-c2 <-  r12 * size2 * size2 +   Cov12 } else {
-c1 <-  size1^2* rbar1 +  sign.max * Cov12  #corrected covariance?
-c2 <-  size2^2 *rbar2 +   Cov12 }
 
 
-if((size1 < 2) && (size2  < 2)) {
+c1 <-  r12 * size1 * size1 +  Cov12    #corrected covariance  
+c2 <-  sign.max*(r12 * size2 * size2 +   Cov12) } else {
+
+c1 <-  size1^2* rbar1 +   Cov12  
+c2 <-  sign.max*(size2^2 *rbar2 +   Cov12) }
+
+
+if((size1 < 2) && (size2  < 2)) { #r2 should be flipped if necessary -- r2 is always flipped (if necessary) when forming clusters 
        r1 <- sqrt(abs(rbar1))   #this  corrects for reliability in a two item cluster
-       r2 <- sign.max* r1         #flips the sign if two are negatively correlated 
+       r2 <- sign.max* r1         #flips the sign if two are negatively correlated  -- in the case of two items 
                              } else {    #this next part corrects for item overlap as well as reliability of the subcluster
                                         
                                  if (ICLUST.options$correct.cluster) {   #correct is the default option
-                                 if(size1 > size2)  {r1 <- c1/sqrt((V1 - size1  +size1 * rbar1) * V12) 
-												       if (size2 < 2)  {r2 <- sign.max * c2/sqrt(abs(rbar2)*V12)}  else  { r2 <- sign.max * c2/sqrt((V2-size2 + size2 * rbar2)*V12c)}
+                                 if(TRUE)  {r1 <- c1/sqrt((V1 - size1  +size1 * rbar1) * V12) 
+												       if (size2 < 2)  {
+												       r2 <- c2/sqrt(abs(rbar2)*V12)}  else  {
+
+												      # r2 <- sign.max * c2/sqrt((V2-size2 + size2 * rbar2)*V12c)}    #changed yet again on 6/10/10
+												       r2 <-  c2/sqrt((V2-size2 + size2 * rbar2)*V12c)}
 												    } else {
-												      if(size1 < 2 )   {r1 <- sign.max * c1/sqrt(abs(rbar1)*V12)} else  {  r1 <- sign.max * c1/sqrt((V1-size1 + size1 * rbar1)*V12c)  }  
-                                     #flip the smaller of the two clusters
-                                                         if (size2 < 2) {r2 <- sign.max* c2/sqrt(abs(rbar2)*V12)} else { r2 <- sign.max* c2/sqrt((V2-size2 + size2*rbar2)*V12c)}
+												      if(size1 < 2 )   {
+												     
+												      r1 <-  c1/sqrt(abs(rbar1)*V12)} else  { 
+												       
+												      r1 <- c1/sqrt((V1-size1 + size1 * rbar1)*V12c)  }  
+                                     #flip the smaller of the two clusters  -- no, flip r2
+                                                         if (size2 < 2) {r2 <- c2/sqrt(abs(rbar2)*V12)} else { r2 <-  c2/sqrt((V2-size2 + size2*rbar2)*V12c)}
 												          #  r2 <-  c2/sqrt((V2-size2+size2*rbar2)*V12c) 
 												          }
 							         
-							} else {if(size1 > size2) {r1 <- c1/sqrt(V1*V12)   #do not correct
+							} else {if(TRUE) {r1 <- c1/sqrt(V1*V12)   #do not correct
 												   r2 <- sign.max* c2/sqrt(V2*V12)
 												    } else {
 												        r1 <-sign.max* c1/sqrt(V1*V12)  } 
-                                     #flip the smaller of the two clusters
+                                     #flip the smaller of the two clusters  - flip r2
 												            r2 <-  c2/sqrt(V2*V12) }
 							
 						}
@@ -263,8 +275,7 @@ results[count,"beta"] <- beta.combined
 results[count,'alpha'] <- alpha
 results[count,'rbar'] <- rbar
 results[count,"size"] <- size12
-#results[count,3:18] <- round(results[count,3:18],ICLUST.options$digits)
-results[count,3:18] <- results[count,3:18]
+
 #update
 cluster.names[max.row] <- paste("C",count,sep="")
 colnames(clusters) <- cluster.names
@@ -284,8 +295,14 @@ if(num.var - count < 1) {keep.clustering <- FALSE}   #only one cluster left
 	
 }  #end of keep clustering loop
 
+#make clusters in the direction of the majority of the items
+#direct <- -(colSums(clusters) < 0 ) 
+#clusters <- t(diag(direct) %*% t(clusters))
+#colnames(clusters) <- cluster.names
+
 ICLUST.cluster <- list(results=results,clusters=clusters,number <- num.var - count)
 }   # end ICLUST.cluster
 #modified June 12, 2008 to  calculate the item-cluster correlation for cluster of size 2
 #modified June 14, 2009 to find weighted or unweighted beta
-#unweighted had been the default option before but it would seem that weighted makes more sense
\ No newline at end of file
+#unweighted had been the default option before but it would seem that weighted makes more sense
+#modified June 5, 2010 to correct the graphic tree paths
\ No newline at end of file
