@@ -1,5 +1,5 @@
 "error.bars" <-
-function (x,stats=NULL,ylab ="Dependent Variable",xlab="Independent Variable",main=NULL,ylim= NULL, alpha=.05, labels=NULL,pos=NULL,arrow.len=.05,add=FALSE,bars=FALSE,within=FALSE,...)  # x   data frame with 
+function (x,stats=NULL,ylab ="Dependent Variable",xlab="Independent Variable",main=NULL,ylim= NULL, alpha=.05, sd=FALSE, labels=NULL,pos=NULL,arrow.len=.05,arrow.col="black",add=FALSE,bars=FALSE,within=FALSE,...)  # x   data frame with 
     {
     if(is.null(stats)) {
     	x.stats <- describe(x)
@@ -15,8 +15,10 @@ function (x,stats=NULL,ylab ="Dependent Variable",xlab="Independent Variable",ma
     	min.x <- min(x.stats$mean,na.rm=TRUE)
     	max.x <- max(x.stats$mean,na.rm=TRUE)
     	max.se <- max(x.stats$se,na.rm=TRUE)
-   		ci <- qt(1-alpha/2,x.stats$n)
-    if(is.null(main)) main = paste((1-alpha)*100,"% confidence limits",sep="") 
+    	 {if(!sd) {
+   		          if(is.null(stats)) {ci <- qt(1-alpha/2,x.stats$n) } else {ci <- rep(1,z) }}  else {ci <- sqrt(x.stats$n) 
+   		           max.se <- max(ci * x.stats$se,na.rm=TRUE)} }
+    if(is.null(main)) {if(!sd) { main = paste((1-alpha)*100,"% confidence limits",sep="") } else {main= paste("Means and standard deviations")} }
     if(is.null(ylim)) {if(is.na(max.x) | is.na(max.se) | is.na(min.x) | is.infinite(max.x)| is.infinite(min.x) | is.infinite(max.se)) {
                         ylim=c(0,1)} else {
                           if(bars) {
@@ -30,10 +32,14 @@ function (x,stats=NULL,ylab ="Dependent Variable",xlab="Independent Variable",ma
      axis(2)
      box()
     } else {
-    if(!add) {plot(x.stats$mean,ylim=ylim,xlab=xlab,ylab=ylab,axes=FALSE,main=main,...)
-     axis(1,1:z,names)
-     axis(2)
-     box()
+    if(!add){
+       if(is.null(x.stats$values)) {
+     plot(x.stats$mean,ylim=ylim,xlab=xlab,ylab=ylab,axes=FALSE,main=main,...) 
+       axis(1,1:z,names)
+       axis(2)
+     box()} else { plot(x.stats$values,x.stats$mean,ylim=ylim,xlab=xlab,ylab=ylab,main=main,...) }
+     
+     
      } else {points(x.stats$mean,...) }
      }  #end of if(bars)
     if(!is.null(labels)) {lab <- labels} else {lab <- paste("V",1:z,sep="")}
@@ -41,10 +47,18 @@ function (x,stats=NULL,ylab ="Dependent Variable",xlab="Independent Variable",ma
      if (length(pos)==0) {locate <- rep(1,z)} else {locate <- pos}
      if (length(labels)==0) lab <- rep("",z) else lab <-labels
       s <- c(1:z)
-    	        if(bars) {arrows(mp[s],x.stats$mean[s]-ci[s]* x.stats$se[s],mp[s],x.stats$mean[s]+ci[s]* x.stats$se[s],length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)} else {
-    	 arrows(s[s],x.stats$mean[s]-ci[s]* x.stats$se[s],s[s],x.stats$mean[s]+ci[s]* x.stats$se[s],length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL) }
+    	        if(bars) {arrows(mp[s],x.stats$mean[s]-ci[s]* x.stats$se[s],mp[s],x.stats$mean[s]+ci[s]* x.stats$se[s],length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)} else { 
+    	        if(is.null(x.stats$values)) {
+    	 arrows(s[s],x.stats$mean[s]-ci[s]* x.stats$se[s],s[s],x.stats$mean[s]+ci[s]* x.stats$se[s],length=arrow.len, angle = 90, code=3,col=arrow.col) } else {
+    	 arrows(x.stats$values,x.stats$mean[s]-ci[s]* x.stats$se[s],x.stats$values,x.stats$mean[s]+ci[s]* x.stats$se[s],length=arrow.len, angle = 90, code=3, col=arrow.col)}
+    	  }
+    	 
+    	  
     	
    }
    #corrected July 25, 2009 to fix bug reported by Junqian Gordon Xu and then modified to be cleaner code
+ 
    #modified Sept 5, 2009 to handle data with all missing values (why we would want to that is a mystery, but was requested by Junqian Gordon Xu.)
-   #April 5, 2010: the within parameter was added to allow for error bars in repeated measure designs 
\ No newline at end of file
+   #April 5, 2010: the within parameter was added to allow for error bars in repeated measure designs 
+   #modified June, 2010 to allow for easier use of stats input
+   #modified June 15, 2010 to allow color bars to match color of lines and to have standard deviations as an option
\ No newline at end of file
