@@ -1,26 +1,32 @@
 "error.bars.by" <-
-function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= NULL, alpha=.05, labels=NULL,pos=NULL,arrow.len=.05,add=FALSE,bars=FALSE,within=FALSE,...)  # x   data frame with 
+function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= NULL, alpha=.05,sd=FALSE, labels=NULL,pos=NULL,arrow.len=.05,add=FALSE,bars=FALSE,within=FALSE,colors=c("black","blue","red"),...)  # x   data frame with 
     {
+    n.color <- length(colors)
     lty = "solid"
     all.stats <- describe(x)
         min.x <- min(all.stats$min,na.rm=TRUE)
    		max.x <- max(all.stats$max,na.rm=TRUE)
     	max.se <- max(all.stats$se,na.rm=TRUE)
+    	if(sd) max.se <- max(all.stats$sd,na.rm=TRUE)
     if(is.null(ylim)) {if(is.na(max.x) | is.na(max.se) | is.na(min.x) | is.infinite(max.x)| is.infinite(min.x) | is.infinite(max.se)) {
                         ylim=c(0,1)} else {
-    ylim=c(min.x - 2*max.se,max.x+2*max.se)}}
-    if(is.null(main)) main <- paste(1-alpha,"% confidence limits",sep="")
+     if(sd) { ylim <- c(min.x - max.se,max.x+max.se) } else {
+    ylim=c(min.x - 2*max.se,max.x+2*max.se)}} }
+    
+    
+    if(is.null(main)) {if(sd) {main <- paste("Means + Standard Deviations") } else {main <- paste(1-alpha,"% confidence limits",sep="")} }
     
     if (bars) { #draw a bar plot and add error bars -- this is ugly but some people like it
     group.stats <- describe.by(x,group,mat=TRUE)   
            n.var <- dim(all.stats)[1]
            n.groups <- length(group.stats[[1]])/n.var
            group.means <- matrix(group.stats$mean,ncol=n.groups,byrow=TRUE)
-           group.se <- matrix(group.stats$se,ncol=n.groups,byrow=TRUE)
+          
+           if(sd) {group.se <- matrix(group.stats$sd,ncol=n.groups,byrow=TRUE)} else { group.se <- matrix(group.stats$se,ncol=n.groups,byrow=TRUE)}
            group.n <- matrix(group.stats$n,ncol=n.groups,byrow=TRUE)
            if(within) {group.smc <- matrix(unlist(by(x,group,smc)),nrow=n.groups,byrow=TRUE)
                        group.sd <- matrix(group.stats$sd,ncol=n.groups,byrow=TRUE)
-                       group.se <- sqrt(group.sd^2 *(1-group.smc)/group.n) }
+                       if(sd) {group.se <- sqrt(group.se^2 * (1-group.smc))} else { group.se <- sqrt(group.sd^2 *(1-group.smc)/group.n) }}
            
            rownames(group.means) <- rownames(all.stats)
            if(is.null(labels)) {colnames(group.means) <- paste("Group",1:n.groups)} else {colnames(group.means) <- labels }
@@ -35,7 +41,7 @@ function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= N
              for (j in 1:n.groups) {
          	 xcen <- group.means[i,j]
     	 	 xse  <- group.se[i,j]
-    	 	ci <- qt(1-alpha,group.n[i,j])
+    	 	if(sd) {ci <- 1} else {ci <- qt(1-alpha,group.n[i,j])}
     	 	
        if(is.finite(xse) && xse>0)    arrows(mp[j,i],xcen-ci*xse,mp[j,i],xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
           }} } else {
@@ -45,7 +51,7 @@ function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= N
              for (j in 1:n.groups) {
          	 xcen <- group.means[i,j]
     	 	 xse  <- group.se[i,j]
-    	 	ci <- qt(1-alpha,group.n[i,j])
+    	 	if(sd) {ci <- 1} else {ci <- qt(1-alpha,group.n[i,j])}
         if(is.finite(xse) && xse>0)     arrows(mp[i,j],xcen-ci*xse,mp[i,j],xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
           }} }
          
@@ -71,14 +77,15 @@ function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= N
     for (g in 1:n.group) {
    	 	x.stats <- group.stats[[g]]
    	 	if (within) { x.smc <- group.smc[[g]]  
-    	              x.stats$se <- sqrt((x.stats$sd^2* (1- x.smc))/x.stats$n)
+    	              if(sd) {x.stats.$se <- sqrt(x.stats$sd^2* (1- x.smc))} else { x.stats$se <- sqrt((x.stats$sd^2* (1- x.smc))/x.stats$n)}
     	               }
 
-    	if(!add) {plot(x.stats$mean,ylim=ylim,xlab=xlab,ylab=ylab,main=main,typ="b",lty=((g-1) %% 8 +1),axes=FALSE,...)
+    	#if(!add) {plot(x.stats$mean,ylim=ylim,xlab=xlab,ylab=ylab,main=main,typ="b",lty=((g-1) %% 8 +1),axes=FALSE,col = colors[(g-1) %% n.color +1])
+    	if(!add) {plot(x.stats$mean,ylim=ylim,xlab=xlab,ylab=ylab,main=main,typ="b",lty=((g-1) %% 8 +1),axes=FALSE)
     	axis(1,1:z,colnames(x))
     	axis(2)
     	box()
-    	} else {points(x.stats$mean,typ="b",lty=((g-1) %% 8 +1),...) }
+    	} else {points(x.stats$mean,typ="b",lty=((g-1) %% 8 +1),col = colors[(g-1) %% n.color +1]) }
     
     	
     	if(!is.null(labels)) {lab <- labels} else {lab <- paste("V",1:z,sep="")}
@@ -87,11 +94,11 @@ function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= N
      	if (length(labels)==0) lab <- rep("",z) else lab <-labels
         for (i in 1:z)  
     	{xcen <- x.stats$mean[i]
-    	# ycen <- y$mean[i]
-    	 xse  <- x.stats$se[i]
-    	# yse <-  y$se[i]
-    	 ci <- qt(1-alpha,x.stats$n[i])
-    	  if(is.finite(xse) & xse>0)  arrows(i,xcen-ci*xse,i,xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)
+    	
+    	 if(sd) {xse <- x.stats$sd[i] } else {xse  <- x.stats$se[i]}
+    	
+    	if(sd) {ci <- 1} else { ci <- qt(1-alpha,x.stats$n[i])}
+    	  if(is.finite(xse) & xse>0)  arrows(i,xcen-ci*xse,i,xcen+ci* xse,length=arrow.len, angle = 90, code=3,col = colors[(g-1) %% n.color +1], lty = NULL, lwd = par("lwd"), xpd = NULL)
     	 
     	#text(xcen,i,labels=lab[i],pos=pos[i],cex=1,offset=arrow.len+1)     #puts in labels for all points
     	}
@@ -111,7 +118,7 @@ function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= N
 
     for (g in 1:n.group) {
    	 	var.means[,g] <- group.stats[[g]]$mean
-   	 	var.se[,g] <- group.stats[[g]]$se 
+   	 	if(sd) {var.se[,g] <- group.stats[[g]]$sd}  else {var.se[,g] <- group.stats[[g]]$se }
    	 	}
    	 	
    	 if(x.cat) {x.values <- 1:n.group}  else {
@@ -136,10 +143,10 @@ function (x,group,by.var=FALSE,x.cat=TRUE,ylab =NULL,xlab=NULL,main=NULL,ylim= N
       
     		xcen <- var.means[i,g]
     	 	xse  <- var.se[i,g]
-    	    ci <- qt(1-alpha,group.stats[[g]]$n)
-    	   if(x.cat)  {arrows(g,xcen-ci[i]*xse,g,xcen+ci[i]* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)}  else {
+    	   if(sd) {ci <- 1} else { ci <- qt(1-alpha,group.stats[[g]]$n)}
+    	   if(x.cat)  {arrows(g,xcen-ci[i]*xse,g,xcen+ci[i]* xse,length=arrow.len, angle = 90, code=3, col = colors[(i-1) %% n.color +1], lty = NULL, lwd = par("lwd"), xpd = NULL)}  else {
     	    
-    	            arrows(x.values[g],xcen-ci[i]*xse,x.values[g],xcen+ci[i]* xse,length=arrow.len, angle = 90, code=3,col = par("fg"), lty = NULL, lwd = par("lwd"), xpd = NULL)} 
+    	            arrows(x.values[g],xcen-ci[i]*xse,x.values[g],xcen+ci[i]* xse,length=arrow.len, angle = 90, code=3,col = colors[(i-1) %% n.color +1], lty = NULL, lwd = par("lwd"), xpd = NULL)} 
     	  #text(xcen,i,labels=lab[i],pos=pos[i],cex=1,offset=arrow.len+1)     #puts in labels for all points
     		}
   
