@@ -1,5 +1,5 @@
 "pairs.panels" <-
-function (x, smooth = TRUE, scale = FALSE, density=TRUE,ellipses=TRUE,digits = 2, pch = 20,lm=FALSE,jiggle=FALSE,factor=2,...)   #combines a splom, histograms, and correlations
+function (x, smooth = TRUE, scale = FALSE, density=TRUE,ellipses=TRUE,digits = 2, pch = 20,lm=FALSE,jiggle=FALSE,factor=2,hist.col="cyan",show.points=TRUE,...)   #combines a splom, histograms, and correlations
 {
 
 "panel.jiggle" <- 
@@ -22,36 +22,90 @@ function (x, y,  pch = par("pch"),
 
   panel.ellipse1(xm,ym,xs,ys,r,col=col.smooth,...)
 }
-    op <- par(no.readonly = TRUE)  # save the whole list of settable par's.
+
+"panel.hist.density" <-
+function(x,...) {
+ usr <- par("usr"); on.exit(par(usr))
+   par(usr = c(usr[1:2], 0, 1.5) )
+    h <- hist(x, plot = FALSE)
+    breaks <- h$breaks; nB <- length(breaks)
+  y <- h$counts; y <- y/max(y)
+    rect(breaks[-nB], 0, breaks[-1], y,col=hist.col)
+  tryd <- try( d <- density(x,na.rm=TRUE,bw="nrd",adjust=1.2),silent=TRUE)
+  if(class(tryd) != "try-error") {
+  
+     d$y <- d$y/max(d$y)
+   lines(d)}
+}
+
+"panel.hist" <-
+function(x, ...)
+{
+    usr <- par("usr"); on.exit(par(usr))
+   par(usr = c(usr[1:2], 0, 1.5) )
+    h <- hist(x, plot = FALSE)
+    breaks <- h$breaks; nB <- length(breaks)
+  y <- h$counts; y <- y/max(y)
+    rect(breaks[-nB], 0, breaks[-1], y,col=hist.col)
+}
+
+#Beginning of the main function
+#the organization gets around the problem of passing parameters to pairs by calling different routines
+
+op <- par(no.readonly = TRUE)  # save the whole list of settable par's.
     par(pch = pch)
     
-    if(!lm) {if (density) {
+    if(!lm) {if (density) { #the basic default is here
       if (smooth) {
         if (scale) { 
             if(ellipses) {
-            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale, lower.panel = panel.smoother, ...) } else {
-             pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale, lower.panel = panel.smooth, ...)}
+              if(show.points) { 
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale, lower.panel = panel.smoother, ...)  } else {
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale, lower.panel = panel.smoother.no, ...)}}  else {
+            if(show.points) {
+             pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale, lower.panel = panel.smoother.noellipse, ...)}  else {
+             pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale, lower.panel = panel.smoother.no.noellipse, ...)}}
         }  #don't scale
-        else { #smooth and density 
+        
+        else { # don't scale, but show density 
         if(ellipses)  { if (jiggle) {  pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor, lower.panel = panel.jiggle , ...)
                        } else {
-            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor, lower.panel = panel.smoother , ...) }} else {
-            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor, lower.panel = panel.smooth, ...) }
+                        if(show.points) {
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor, lower.panel = panel.smoother, ...)} else {
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor, lower.panel = panel.smoother.no , ...) }   }
+            } else {
+              if(show.points) {
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor, lower.panel = panel.smoother.noellipse, ...)} else {
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor, lower.panel = panel.smoother.no.noellipse, ...)} }
           }
-      # }
+     
+      
     }  #don't smooth
     else {
         if (scale) {
              if(ellipses) {
+              if(show.points) {
             pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale,lower.panel=panel.ellipse,  ...) } else {
-            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale,  ...)}
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale,lower.panel=panel.ellipse.no,  ...)}
+            } else {
+            if(show.points) {
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale,  ...)} else {
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor.scale, lower.panel=panel.ellipse.no, ...)}}
         }
-        else { #don't smooth, don't scale
+        else { #don't smooth, don't scale, not lm
             if(ellipses) {
-            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor,lower.panel=panel.ellipse, ...) } else {
-              pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor, ...) } 
+            if(show.points) { pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor,lower.panel=panel.ellipse, ...) } else {
+                     pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor,lower.panel=panel.ellipse.no, ...)
+           }} else {
+           if(show.points) {
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor, ...) } else {
+            pairs(x, diag.panel = panel.hist.density, upper.panel = panel.cor, lower.panel = panel.ellipse.no, ...)}
+            } 
         }
     }
+    
+    
+    
     } else { # no densities
     if (smooth) {
         if (scale) {
@@ -70,14 +124,20 @@ function (x, y,  pch = par("pch"),
          if(ellipses) {
             pairs(x, diag.panel = panel.hist, upper.panel = panel.cor.scale,lower.panel=panel.ellipse,  ...) } else { 
             pairs(x, diag.panel = panel.hist, upper.panel = panel.cor.scale,  ...)} 
-        }
-        else {
+        }  else {
            if(ellipses) {
-            pairs(x, diag.panel = panel.hist, upper.panel = panel.cor,lower.panel=panel.ellipse, ...) } else {
+           if(show.points) {
+            pairs(x, diag.panel = panel.hist, upper.panel = panel.cor,lower.panel=panel.ellipse, ...)} else { 
+            pairs(x, diag.panel = panel.hist, upper.panel = panel.cor,lower.panel=panel.ellipse.no, ...)  }} else {
             pairs(x, diag.panel = panel.hist, upper.panel = panel.cor, ...)} 
         }
     }
     }
+    
+    
+    
+    
+    
     } else { #lm is TRUE
     
         if (density) {
@@ -90,7 +150,7 @@ function (x, y,  pch = par("pch"),
      	                      pairs(x, diag.panel = panel.hist, upper.panel = panel.lm, lower.panel = panel.lm, ...)}
    			 }
    			   }
-    op <- par(op)
+ par(op)
 }
 
  "panel.lm" <- 
@@ -132,32 +192,8 @@ function (x, y, pch = par("pch"),
    
 }
 
-"panel.hist.density" <-
-function(x, ...)
-{
-    usr <- par("usr"); on.exit(par(usr))
-   par(usr = c(usr[1:2], 0, 1.5) )
-    h <- hist(x, plot = FALSE)
-    breaks <- h$breaks; nB <- length(breaks)
-  y <- h$counts; y <- y/max(y)
-    rect(breaks[-nB], 0, breaks[-1], y, col="cyan")
-  tryd <- try( d <- density(x,na.rm=TRUE,bw="nrd",adjust=1.2),silent=TRUE)
-  if(class(tryd) != "try-error") {
-  
-     d$y <- d$y/max(d$y)
-   lines(d)}
-}
 
-"panel.hist" <-
-function(x, ...)
-{
-    usr <- par("usr"); on.exit(par(usr))
-   par(usr = c(usr[1:2], 0, 1.5) )
-    h <- hist(x, plot = FALSE)
-    breaks <- h$breaks; nB <- length(breaks)
-  y <- h$counts; y <- y/max(y)
-    rect(breaks[-nB], 0, breaks[-1], y, col = "cyan")
-}
+
 
 
 "panel.cor" <-
@@ -204,6 +240,28 @@ angles <- (0:segments) * 2 * pi/segments
    lines(ellipse, ...)   }    
 }
 
+"panel.ellipse.no" <-
+function (x, y,   pch = par("pch"), 
+     col.smooth = "red", ...) 
+ { segments=51
+ xm <- mean(x,na.rm=TRUE)
+  ym <- mean(y,na.rm=TRUE)
+  xs <- sd(x,na.rm=TRUE)
+  ys <- sd(y,na.rm=TRUE)
+   r = (cor(x, y,use="pairwise"))
+#points(x, y, pch = pch, ...)
+ angles <- (0:segments) * 2 * pi/segments
+    unit.circle <- cbind(cos(angles), sin(angles))
+     if(!is.na(r)) {
+  if (abs(r)>0 ) theta <- sign(r)/sqrt(2) else theta=1/sqrt(2) 
+
+  shape <- diag(c(sqrt(1+r),sqrt(1-r))) %*% matrix(c(theta,theta,-theta,theta),ncol=2,byrow=TRUE)
+   ellipse <- unit.circle %*% shape 
+   ellipse[,1] <- ellipse[,1]*xs + xm
+   ellipse[,2] <- ellipse[,2]*ys + ym
+   points(xm,ym,pch=19,col=col.smooth,cex=1.5 )  #draw the mean
+   lines(ellipse, ...)   }    
+}
 
 "panel.ellipse" <-
 function (x, y,   pch = par("pch"), 
@@ -214,7 +272,7 @@ function (x, y,   pch = par("pch"),
   xs <- sd(x,na.rm=TRUE)
   ys <- sd(y,na.rm=TRUE)
    r = (cor(x, y,use="pairwise"))
-  points(x, y, pch = pch, ...)
+ points(x, y, pch = pch, ...)
  angles <- (0:segments) * 2 * pi/segments
     unit.circle <- cbind(cos(angles), sin(angles))
      if(!is.na(r)) {
@@ -222,9 +280,9 @@ function (x, y,   pch = par("pch"),
 
   shape <- diag(c(sqrt(1+r),sqrt(1-r))) %*% matrix(c(theta,theta,-theta,theta),ncol=2,byrow=TRUE)
    ellipse <- unit.circle %*% shape 
-   ellipse[,1] <- ellipse[,1]*xs + x
-   ellipse[,2] <- ellipse[,2]*ys + y
-   points(x,y,pch=19,col=col.smooth,cex=1.5 )  #draw the mean
+   ellipse[,1] <- ellipse[,1]*xs + xm
+   ellipse[,2] <- ellipse[,2]*ys + ym
+   points(xm,ym,pch=19,col=col.smooth,cex=1.5 )  #draw the mean
    lines(ellipse, ...)   }    
 }
  
@@ -250,4 +308,59 @@ function (x, y,pch = par("pch"),
   panel.ellipse1(xm,ym,xs,ys,r,col=col.smooth,...)
 }
 
+"panel.smoother.no" <- 
+function (x, y,pch = par("pch"), 
+    col.smooth = "red", span = 2/3, iter = 3, ...) 
+{
+  
+  xm <- mean(x,na.rm=TRUE)
+  ym <- mean(y,na.rm=TRUE)
+  xs <- sd(x,na.rm=TRUE)
+  ys <- sd(y,na.rm=TRUE)
+  r = cor(x, y,use="pairwise")
+ 
+  #points(x, y, pch = pch, ...)
+    ok <- is.finite(x) & is.finite(y)
+    if (any(ok)) 
+        lines(stats::lowess(x[ok], y[ok], f = span, iter = iter), 
+            col = col.smooth, ...)
 
+  panel.ellipse1(xm,ym,xs,ys,r,col=col.smooth,...)
+}
+
+
+"panel.smoother.noellipse" <- 
+function (x, y,pch = par("pch"), 
+    col.smooth = "red", span = 2/3, iter = 3, ...) 
+{
+  
+  xm <- mean(x,na.rm=TRUE)
+  ym <- mean(y,na.rm=TRUE)
+  xs <- sd(x,na.rm=TRUE)
+  ys <- sd(y,na.rm=TRUE)
+  r = cor(x, y,use="pairwise")
+ 
+  points(x, y, pch = pch, ...)
+    ok <- is.finite(x) & is.finite(y)
+    if (any(ok)) 
+        lines(stats::lowess(x[ok], y[ok], f = span, iter = iter), 
+            col = col.smooth, ...)
+}
+
+"panel.smoother.no.noellipse" <- 
+function (x, y,pch = par("pch"), 
+    col.smooth = "red", span = 2/3, iter = 3, ...) 
+{
+  
+  xm <- mean(x,na.rm=TRUE)
+  ym <- mean(y,na.rm=TRUE)
+  xs <- sd(x,na.rm=TRUE)
+  ys <- sd(y,na.rm=TRUE)
+  r = cor(x, y,use="pairwise")
+ 
+  #points(x, y, pch = pch, ...)
+    ok <- is.finite(x) & is.finite(y)
+    if (any(ok)) 
+        lines(stats::lowess(x[ok], y[ok], f = span, iter = iter), 
+            col = col.smooth, ...)
+}
